@@ -5,7 +5,7 @@ require 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '5.05';
+our $VERSION = '5.06';
 my $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION;
 
@@ -36,8 +36,8 @@ use Exception::Class (
 #
 # These hashes are declared using the 'Field' attribute.
 
-my %sources_for :Field;   # Sources from which to obtain random seed data
-my %seed_for    :Field;   # Last seed sent to the PRNG
+my %sources_for :Field :Deep;   # Sources from which to obtain random seed data
+my %seed_for    :Field :Deep;   # Last seed sent to the PRNG
 
 
 ### Standalone PRNG pseudo-object
@@ -702,7 +702,7 @@ Math::Random::MT::Auto - Auto-seeded Mersenne Twister PRNGs
 
 =head1 VERSION
 
-This documentation refers to Math::Random::MT::Auto version 5.05
+This documentation refers to Math::Random::MT::Auto version 5.06
 
 =head1 SYNOPSIS
 
@@ -735,12 +735,12 @@ capable of providing large volumes (> 10^6004) of "high quality" pseudorandom
 data to applications that may exhaust available "truly" random data sources or
 system-provided PRNGs such as L<rand|perlfunc/"rand">.
 
-This module provides PRNGs that are based on the Mersenne Twister.  There
-is a functional interface to a single, standalone PRNG, and an OO interface
-(based on the inside-out object model as implemented by the
-L<Object::InsideOut> module) for generating multiple PRNG objects.  The PRNGs
-are normally self-seeding, automatically acquiring a (19968-bit) random seed
-from user-selectable sources.  (I<Manual> seeding is optionally available.)
+This module provides PRNGs that are based on the Mersenne Twister.  There is a
+functional interface to a single standalone PRNG, and an OO interface (based
+on the inside-out object model as implemented by the L<Object::InsideOut>
+module) for generating multiple PRNG objects.  The PRNGs are normally
+self-seeding, automatically acquiring a (19968-bit) random seed from
+user-selectable sources.  (I<Manual> seeding is optionally available.)
 
 =over
 
@@ -1427,13 +1427,39 @@ B<NOTE:> Code refs cannot be shared between threads. Therefore, you cannot
 use L</"User-defined Seeding Source"> subroutines in conjuction with
 L</"srand"> when C<use threads::shared;> is in effect.
 
-The standalone PRNG can be used safely to generate random numbers in threaded
-applications.  When C<use threads::shared;> is in effect, any operations on
-the standalone PRNG are fully supported.  However, if only C<use threads;> is
-in effect, then changes made to the standalone PRNG in one thread (e.g., by
-calling C<srand()>) will affect the standalone PRNG in other threads in a
-inconsistent manner (e.g., the results of C<get_seed()> will differ between
-the threads).
+Depending on your needs, when using threads, but not enabling thread-sharing
+of PRNG objects as per the above, you may want to perform an C<-E<gt>srand()>
+call on your PRNG objects inside the threaded code so that the pseudo-random
+number sequences generated by those objects in each thread differ:
+
+ use threads;
+ use Math::Random:MT::Auto ':!auto';
+
+ my $prng = Math::Random:MT::Auto->new();
+
+ sub thr_code
+ {
+     $prng->srand();
+
+     ....
+ }
+
+There is only one standalone PRNG, even in threaded applications.  When C<use
+threads::shared;> is in effect, the standalone PRNG is fully shared between
+threads, and all operations on it are fully supported.
+
+When only C<use threads;> is in effect, the number generating portion of the
+standalone PRNG is shared between threads such that unique pseudo-random
+numbers are generated in each thread, and all pseudo-random number generating
+calls (e.g., C<irand()>) as safe to use.  Calls that modify the state of the
+standalone PRNG (e.g., C<srand()>) are safe to make, and will affect the
+standalone PRNG as expected.  However, such state-modifying calls made in one
+thread will affect subsequent calls that query or make use of the current
+state of the standalone PRNG in other threads in an inconsistent manner.  For
+example, C<get_seed()> called in one thread will still return the old seed
+after C<srand()> is called in some other thread.  The bottom line is that if
+you don't make use of C<get_seed()> or C<set_seed()>, and you only call
+C<srand()> is with no arguments, then this caveat should be of no concern.
 
 =head1 EXAMPLES
 
@@ -1697,7 +1723,7 @@ Math::Random::MT::Auto Discussion Forum on CPAN:
 L<http://www.cpanforum.com/dist/Math-Random-MT-Auto>
 
 Annotated POD for Math::Random::MT::Auto:
-L<http://annocpan.org/~JDHEDDEN/Math-Random-MT-Auto-5.05/lib/Math/Random/MT/Auto.pm>
+L<http://annocpan.org/~JDHEDDEN/Math-Random-MT-Auto-5.06/lib/Math/Random/MT/Auto.pm>
 
 Source repository:
 L<http://code.google.com/p/mrma/>
